@@ -1,12 +1,12 @@
 /*
  * libopenraw - orffile.h
  *
- * Copyright (C) 2006-2007 Hubert Figuiere
+ * Copyright (C) 2006-2008 Hubert Figuiere
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This library is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3 of
+ * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * License along with this library.  If not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 
@@ -39,8 +39,8 @@ namespace OpenRaw {
 			: public IFDFile
 		{
 		public:
-			static RawFile *factory(const char* _filename);
-			ORFFile(const char* _filename);
+			static RawFile *factory(IO::Stream *);
+			ORFFile(IO::Stream *);
 			virtual ~ORFFile();
 
 		protected:
@@ -49,9 +49,12 @@ namespace OpenRaw {
 
 			virtual ::or_error _getRawData(RawData & data, uint32_t options);
 		private:
+			static RawFile::TypeId _typeIdFromModel(const std::string & model);
 
 			ORFFile(const ORFFile&);
 			ORFFile & operator=(const ORFFile &);
+
+			static const IFDFile::camera_ids_t s_def[];
 		};
 	}
 
